package com.zanxiang.manage.service.Impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.zanxiang.common.utils.bean.BeanUtils;
import com.zanxiang.manage.domain.params.GamePictureParam;
import com.zanxiang.manage.domain.vo.GamePictureVO;
import com.zanxiang.manage.service.GamePictureService;
import com.zanxiang.mybatis.entity.GamePicture;
import com.zanxiang.mybatis.mapper.GamePictureMapper;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import java.time.LocalDateTime;

/**
 * @author : lingfeng
 * @time : 2022-07-12
 * @description : 游戏图片
 */
@Slf4j
@Service
public class GamePictureServiceImpl extends ServiceImpl<GamePictureMapper, GamePicture> implements GamePictureService {

    /**
     * 根据游戏id查询
     *
     * @param gameId : 游戏id
     * @return 返回游戏图片信息
     */
    @Override
    public GamePictureVO getByGameId(Long gameId) {
        GamePicture gamePicture = super.getOne(new LambdaQueryWrapper<GamePicture>().eq(GamePicture::getGameId, gameId));
        if (gamePicture == null) {
            gamePicture = GamePicture.builder().gameId(gameId).build();
        }
        return BeanUtils.copy(gamePicture, GamePictureVO.class);
    }

    /**
     * 游戏图片添加或更新
     *
     * @param param : 游戏图片参数
     * @return : 返回更新结果
     */
    @Override
    public Boolean addOrUpdate(GamePictureParam param) {
        Long gameId = param.getGameId();
        GamePicture gamePicture = super.getOne(new LambdaQueryWrapper<GamePicture>().eq(GamePicture::getGameId, gameId));
        if (gamePicture == null) {
            gamePicture = GamePicture.builder()
                    .gameId(gameId)
                    .avatarImg(param.getAvatarImg())
                    .appletImg(param.getAppletImg())
                    .cardTitle(param.getCardTitle())
                    .cardUrl(param.getCardUrl())
                    .cardImg(param.getCardImg())
                    .isOpenInlet(param.getIsOpenInlet())
                    .inletImg(param.getInletImg())
                    .findImg(param.getFindImg())
                    .recommendImg(param.getRecommendImg())
                    .tryPayImg(param.getTryPayImg())
                    .shareImgName(param.getShareImgName())
                    .shareImg(param.getShareImg())
                    .createTime(LocalDateTime.now())
                    .updateTime(LocalDateTime.now())
                    .build();
        } else {
            gamePicture.setAvatarImg(param.getAvatarImg());
            gamePicture.setAppletImg(param.getAppletImg());
            gamePicture.setCardTitle(param.getCardTitle());
            gamePicture.setCardUrl(param.getCardUrl());
            gamePicture.setCardImg(param.getCardImg());
            gamePicture.setIsOpenInlet(param.getIsOpenInlet());
            gamePicture.setInletImg(param.getInletImg());
            gamePicture.setFindImg(param.getFindImg());
            gamePicture.setRecommendImg(param.getRecommendImg());
            gamePicture.setTryPayImg(param.getTryPayImg());
            gamePicture.setShareImgName(param.getShareImgName());
            gamePicture.setShareImg(param.getShareImg());
            gamePicture.setUpdateTime(LocalDateTime.now());
        }
        return super.saveOrUpdate(gamePicture);
    }
}
